==> sca-patterns-sle15-1.5.5.tar.gz: sca-patterns-sle15-1.5.5/patterns/SLE/sle15sp1/qemu_SUSE-SU-2022_3768-1_sles_15.1.ltss.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for qemu SUSE-SU-2022:3768-1
# Description: Security fixes for SUSE Linux Enterprise 15 SP1 LTSS
# URL:         https://lists.suse.com/pipermail/sle-security-updates/2022-October/012710.html
# Source:      Security Announcement Generator (sagen.py) v2.0.6
# Modified:    2023 Jun 13
#
##############################################################################
# Copyright (C) 2023 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

meta_class = "Security"
meta_category = "SLE"
meta_component = "qemu"
pattern_filename = os.path.basename(__file__)
primary_link = "META_LINK_Security"
overall = Core.TEMP
overall_info = "NOT SET"
other_links = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2022-October/012710.html"
Core.init(meta_class, meta_category, meta_component, pattern_filename, primary_link, overall, overall_info, other_links)

def main():
	ltss = True
	name = 'qemu'
	main = ''
	severity = 'Important'
	tag = 'SUSE-SU-2022:3768-1'
	packages = {}
	server = SUSE.getHostInfo()

	if ( server['DistroVersion'] == 15):
		if ( server['DistroPatchLevel'] == 1 ):
			packages = {
				'qemu': '3.1.1.1-150100.80.43.2',
				'qemu-block-curl': '3.1.1.1-150100.80.43.2',
				'qemu-block-curl-debuginfo': '3.1.1.1-150100.80.43.2',
				'qemu-block-iscsi': '3.1.1.1-150100.80.43.2',
				'qemu-block-iscsi-debuginfo': '3.1.1.1-150100.80.43.2',
				'qemu-block-rbd': '3.1.1.1-150100.80.43.2',
				'qemu-block-rbd-debuginfo': '3.1.1.1-150100.80.43.2',
				'qemu-block-ssh': '3.1.1.1-150100.80.43.2',
				'qemu-block-ssh-debuginfo': '3.1.1.1-150100.80.43.2',
				'qemu-debuginfo': '3.1.1.1-150100.80.43.2',
				'qemu-debugsource': '3.1.1.1-150100.80.43.2',
				'qemu-guest-agent': '3.1.1.1-150100.80.43.2',
				'qemu-guest-agent-debuginfo': '3.1.1.1-150100.80.43.2',
				'qemu-lang': '3.1.1.1-150100.80.43.2',
				'qemu-tools': '3.1.1.1-150100.80.43.2',
				'qemu-tools-debuginfo': '3.1.1.1-150100.80.43.2',
			}
			SUSE.securityAnnouncementPackageCheck(name, main, ltss, severity, tag, packages)
		else:
			Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the service pack scope")
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the distribution scope")

	Core.printPatternResults()

if __name__ == "__main__":
	main()

==> sca-patterns-sle15-1.5.8.tar.gz: sca-patterns-sle15-1.5.8/patterns/SLE/sle15sp1/qemu_SUSE-SU-2023_0877-1_sles_15.1.ltss.py <==
#!/usr/bin/python3
#
# Title:       Important Security Announcement for qemu SUSE-SU-2023:0877-1
# Description: Security fixes for SUSE Linux Enterprise 15 SP1 LTSS
# URL:         https://lists.suse.com/pipermail/sle-security-updates/2023-March/014147.html
# Source:      Security Announcement Generator (sagen.py) v2.0.6
# Modified:    2023 Jun 13
#
##############################################################################
# Copyright (C) 2023 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import os
import Core
import SUSE

meta_class = "Security"
meta_category = "SLE"
meta_component = "qemu"
pattern_filename = os.path.basename(__file__)
primary_link = "META_LINK_Security"
overall = Core.TEMP
overall_info = "NOT SET"
other_links = "META_LINK_Security=https://lists.suse.com/pipermail/sle-security-updates/2023-March/014147.html"
Core.init(meta_class, meta_category, meta_component, pattern_filename, primary_link, overall, overall_info, other_links)

def main():
	ltss = True
	name = 'qemu'
	main = ''
	severity = 'Important'
	tag = 'SUSE-SU-2023:0877-1'
	packages = {}
	server = SUSE.getHostInfo()

	if ( server['DistroVersion'] == 15):
		if ( server['DistroPatchLevel'] == 1 ):
			packages = {
				'qemu-arm': '3.1.1.1-150100.80.46.1',
				'qemu-arm-debuginfo': '3.1.1.1-150100.80.46.1',
			}
			SUSE.securityAnnouncementPackageCheck(name, main, ltss, severity, tag, packages)
		else:
			Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the service pack scope")
	else:
		Core.updateStatus(Core.ERROR, "ERROR: " + name + " Security Announcement: Outside the distribution scope")

	Core.printPatternResults()

if __name__ == "__main__":
	main()
